==> haskell-ansi-wl-pprint-0.6.8.2-18-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-ansi-wl-pprint.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: ansi-wl-pprint
version: 0.6.8.2
id: ansi-wl-pprint-0.6.8.2-Bo6ysK7CsNLHN6Mrx4aKYi
key: ansi-wl-pprint-0.6.8.2-Bo6ysK7CsNLHN6Mrx4aKYi
license: BSD-3-Clause
maintainer: Edward Kmett <ekmett@gmail.com>
author: Daan Leijen, Max Bolingbroke
homepage: http://github.com/ekmett/ansi-wl-pprint
synopsis: The Wadler/Leijen Pretty Printer for colored ANSI terminal output
description:
    This is a pretty printing library based on Wadler'\''s paper ["A Prettier Printer"](https://homepages.inf.ed.ac.uk/wadler/papers/prettier/prettier.pdf). It has been enhanced with support for ANSI terminal colored output using the [ansi-terminal](https://hackage.haskell.org/package/ansi-terminal) package.
category: User Interfaces, Text
abi: 16741b31c77af5a943d00d6c4b6cfea3
exposed: True
exposed-modules:
    Text.PrettyPrint.ANSI.Leijen Text.PrettyPrint.ANSI.Leijen.Internal
import-dirs: /usr/lib/ghc-8.6.5/site-local/ansi-wl-pprint-0.6.8.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/ansi-wl-pprint-0.6.8.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/ansi-wl-pprint-0.6.8.2
hs-libraries: HSansi-wl-pprint-0.6.8.2-Bo6ysK7CsNLHN6Mrx4aKYi
depends:
    ansi-terminal-0.8.2-IytGdmUG1lK1dAjqEeG5cq base-4.12.0.0
haddock-interfaces: /usr/share/doc/haskell-ansi-wl-pprint/html/ansi-wl-pprint.haddock
haddock-html: /usr/share/doc/haskell-ansi-wl-pprint/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ansi-wl-pprint-0.6.8.2-20-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-ansi-wl-pprint.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: ansi-wl-pprint
version: 0.6.8.2
id: ansi-wl-pprint-0.6.8.2-1XkQt2TkKXp58Z2fWGaSDQ
key: ansi-wl-pprint-0.6.8.2-1XkQt2TkKXp58Z2fWGaSDQ
license: BSD-3-Clause
maintainer: Edward Kmett <ekmett@gmail.com>
author: Daan Leijen, Max Bolingbroke
homepage: http://github.com/ekmett/ansi-wl-pprint
synopsis: The Wadler/Leijen Pretty Printer for colored ANSI terminal output
description:
    This is a pretty printing library based on Wadler'\''s paper ["A Prettier Printer"](https://homepages.inf.ed.ac.uk/wadler/papers/prettier/prettier.pdf). It has been enhanced with support for ANSI terminal colored output using the [ansi-terminal](https://hackage.haskell.org/package/ansi-terminal) package.
category: User Interfaces, Text
abi: 73d85c3659c643527ae09e2d1c8793c6
exposed: True
exposed-modules:
    Text.PrettyPrint.ANSI.Leijen Text.PrettyPrint.ANSI.Leijen.Internal
import-dirs: /usr/lib/ghc-8.6.5/site-local/ansi-wl-pprint-0.6.8.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/ansi-wl-pprint-0.6.8.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/ansi-wl-pprint-0.6.8.2
hs-libraries: HSansi-wl-pprint-0.6.8.2-1XkQt2TkKXp58Z2fWGaSDQ
depends:
    ansi-terminal-0.8.2-LbawE0xYmiu2QkRGz1IZXL base-4.12.0.0
haddock-interfaces: /usr/share/doc/haskell-ansi-wl-pprint/html/ansi-wl-pprint.haddock
haddock-html: /usr/share/doc/haskell-ansi-wl-pprint/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
